# PyPI demo package for testing links

PyPI allows to add custom links to projects and it has some special icons based
on either the name or URL of the link:

```
[project.urls]
# Name based
Homepage = "https://example.com/"
Changelog = "https://example.com/"
Documentation = "https://example.com/"
Download = "https://example.com/"
Sponsor = "https://example.com/"
Source = "https://github.com/patrick91/links-demo"
Issues = "https://example.com/"

# URL based
Appveyor = "https://ci.appveyor.com/project/example"
Bitbucket = "https://bitbucket.org/example"
CircleCI = "https://circleci.com/example"
Codecov = "https://codecov.io/example"
Discord = "https://discord.gg/example"
Coveralls = "https://coveralls.io/example"
Gitlab = "https://gitlab.com/example"
Gitter = "https://gitter.im/example"
Google = "https://google.com/example"
Pypi = "https://pypi.org/project/links-demo"
Python = "https://www.python.org/example"
Reddit = "https://www.reddit.com/r/example"
Slack = "https://something.slack.com/example"
Twitter = "https://twitter.com/example"
Youtube = "https://www.youtube.com/example"
```

Example on PyPI:

![](./meta/screen.png)
